@@ -159,13 +159,13 @@ class SDK:
         headers = {
             'apikey': self.api_key
         }
-        payload = json.dumps({
+        payload = {
             "categorySchema": {
                 "tools": list(map(lambda t: t.toDict(), tools)),
                 "classifications": [],
                 "relations": []
-            }}
-        )
+            }
+        }
 
-        response = requests.request("POST", url, headers=headers, data=payload)
+        response = requests.request("POST", url, headers=headers, json=payload)
         return response.json()
